==> campsite-2.6.1.tar.gz: campsite/implementation/management/priv/lang/sh/articles.php <==
<?php 
regGS("Select location:", "");
regGS("You cannot have two articles in the same section with the same name.  The article name you specified is already in use by the article '$1'.", "");
regGS("Visible to non-subscribers", "");
regGS("The article could not be published.", "");
regGS("Scheduled action deleted.", "");
regGS("Scheduled action added.", "");
regGS("Article(s) unlocked.", "");
regGS("Article(s) duplicated.", "");
regGS("Article(s) deleted.", "");
regGS("Article status set to '$1'", "");
regGS("Article unlocked.", "");
regGS("Article translation created.", "");
regGS("Article order changed.", "");
regGS("Article moved.", "");
regGS("Article deleted.", "");
regGS("Article created.", "");
regGS("$1 toggled.", "");
regGS("Total:", "");
regGS("Toggle '$1'", "");
regGS("Show Comments", "");
regGS("Saved:", "");
regGS("Locked", "");
regGS("Link to public page", "");
regGS("Invalid type: $1", "");
regGS("Hide Comments", "");
regGS("Enabled", "");
regGS("Disabled", "");
regGS("Comments:", "");
regGS("Comments", "");
regGS("The article has already been translated into $1.", "Tekst je već preveden na $1.");
regGS("You must set the publication, issue, and section for this article before you can schedule it for publishing.  Go to the \"$1\" menu and select \"$2\" to do this.", "Moraš odrediti publikaciju, izdanje i rubriku za ovaj tekst pre nego što mu zakažete automatsko objavljivanje. Idite u meni \"$1\" i izaberi \"$2\"");
regGS("You do not have the right to translate articles.", "Nemate pravo da prevodite tekstove.");
regGS("You do not have the right to publish articles.", "Nemate pravo da objavljujete tekstove.");
regGS("You do not have the right to move articles.", "Nemate pravo da premeštate tekstove.");
regGS("You cannot $1 the articles marked in red because the destination issue has not been translated into the appropriate language.", "Ne možete vršiti radnju \"$1\" na tekstovima naglašenim crvenom bojom jer ciljno izdanje nije prevedeno na odgovarajući jezik.");
regGS("Publish?", "Objavi?");
regGS("Publish articles", "Objavi tekstove");
regGS("Publish article", "Objavi tekst");
regGS("Move?", "Premesti?");
regGS("Move articles", "Premesti tekstove");
regGS("Move article", "Premesti tekst");
regGS("An issue must be created for the selected language but you do not have the right to create an issue.", "Mora biti kreirano izdanje za odabrani jezik, ali vi nemate pravo da kreirate izdanje.");
regGS("A section must be created for the selected language but you do not have the right to create a section.", "Mora biti kreirana rubrika za odabrani jezik, ali vi nemate pravo da kreirate rubriku.");
regGS("to section", "u rubriku");
regGS("You must select at least one article to perform an action.", "Morate izabrati najmanje jedan tekst da bi radnja bila izvršena.");
regGS("You must choose a language", "Morate izabrati jezik");
regGS("You may only translate one article at a time.", "Možete prevoditi samo jedan tekst u jednom trenutku.");
regGS("View article", "Pogledaj tekst");
regGS("Unable to create the section for translation $1.", "Ne može biti kreirana rubrika za prevod  $1.");
regGS("Unable to create the issue for translation $1.", "Ne može biti kreirano izdanje za prevod  $1.");
regGS("The following articles are new; it is not possible to schedule them for automatic publishing", "Sledeći tekstovi su novi; nemoguće je predvideti ih za automatsko objavljivanje");
regGS("Status: Submitted", "Status: predat");
regGS("Status: Submit", "Status: predaj");
regGS("Status: Set New", "Status: postavi novi");
regGS("Status: Published", "Status: objavljen");
regGS("Status: Publish", "Status: objavi");
regGS("Status: New", "Status: novi");
regGS("Section URL Name", "URL ime rubrike");
regGS("Section Name", "Ime rubrike");
regGS("Publish date", "Datum objavljivanja");
regGS("Publish Schedule", "Raspored objavljivanja");
regGS("No action specified", "Nije predviđena nikakva radnja");
regGS("New section name", "Novo ime rubrike");
regGS("New section URL name", "Novo URL ime rubrike");
regGS("New issue name", "novo ime izdanja");
regGS("New issue URL name", "Novo URL ime izdanja");
regGS("New article name", "Novo ime teksta");
regGS("Issue URL Name", "URL ime izdanja");
regGS("Issue Name", "Ime izdanja");
regGS("Files", "Fajlovi");
regGS("Duplicate?", "Dupliraj?");
regGS("Duplicate to another section", "dupliraj u drugu rubriku");
regGS("Duplicate articles", "dupliraj tekstove");
regGS("Article name ($1)", "Ime teksta ($1)");
regGS("Article List", "Lista tekstova");
regGS("Are you sure you want to remove the topic \'$1\' from the article?", "Da li ste sigurni da iz teksta želite da uklonite temu \'$1\'?");
regGS("Are you sure you want to remove the file \'$1\' from the article?", "Da li ste sigurni da iz teksta želite da uklonite fajl \'$1\'?");
regGS("Are you sure you want to remove the event scheduled on $1?", "Da li ste sigurni da želite da uklonite zakazanu akciju za $1?");
regGS("Are you sure you want to delete this article?", "Da li ste sigurni da želite da obrišete tekst?");
regGS("Are you sure you want to delete the selected articles?", "Da li ste sigurni da želite da obrišete izabrane tekstove?");
regGS("An issue must be created for the selected language.  Please enter the issue name and URL name.", "Mora biti kreirano izdanje za odabrani jezik. Unesite ime izdanja i URL ime.");
regGS("A section must be created for the selected language.  Please enter the section name and URL name.", "Mora biti kreirana rubrika za odabrani jezik. Unesite ime rubrike i URL ime.");
regGS("Article Type", "Tip teksta");
regGS("$1 articles found", "Pronađeno je $1 tekstova");
regGS("Show article on front page", "Prikaži tekst na početnoj strani");
regGS("Show article on section page", "Prikaži tekst na strani rubrike");
regGS("Translate article", "Prevedi tekst");
regGS("You do not have the right to change this article.  You may only edit your own articles and once submitted an article can only be changed by authorized users.", "Nemate pravo da menjate tekst. Možete pregledati jedino sopstvene tekstove, a jednom predati tekst može biti menjan samo od strane ovlašćenih korisnika");
regGS("Edit article", "Uredi tekst");
regGS("The article has been locked by $1 ($2) $3 hour(s) and $4 minute(s) ago.", "Tekst je zaključao $1 ($2) pre $3 časova i $4 minuta. ");
regGS("The article has been locked by $1 ($2) $3 minute(s) ago.", "Tekst je zaključao $1 ($2) pre $3 minuta. ");
regGS("Article is locked", "Tekst je zaključan");
regGS("Duplicate article", "Dupliraj tekst");
regGS("The destination section is the same as the source section.", "Ciljna rubrika je ista kao matična.");
regGS("The article is new; it is not possible to schedule it for automatic publishing.", "Tekst ima status novi; nemoguće je zakazati akciju automatskog objavljivanja.");
regGS("No article types were defined. You must create an article type first.", "Nema definisanih tipova tekstova. Morate kreirati neki.");
regGS("Edit article types", "Uredi tipove tekstova");
regGS("Could not save the article. It has been locked by $1 $2 hours and $3 minutes ago.", "Tekst ne može biti snimljen. Zaključan je od strane $1 pre $2časova i $3 minuta.");
regGS("You do not have the right to change this article status. Once submitted an article can only be changed by authorized users.", "Nemate pravo da menajte status teksta. Predatom tekstu status može promeniti samo ovlašćeni korisnik.");
regGS("You do not have the right to delete articles.", "Nemate pravo da brišete tekstove.");
regGS("You must select an article type.", "Morate izabrati tip teksta.");
regGS("Are you sure you want to remove the image \'$1\' from the article?", "Da li ste sigurni da iz teksta želite da uklonite sliku \'$1\'?");
regGS("Are you sure you want to delete this scheduled action?", " ");
regGS("Are you sure you want to remove the image '$1' from the article?", "Da li ste sigurni da želite da obrišete sliku $1 iz članka?");
regGS("There was an error reading request parameters.", "Greška pri čitanju traženih parametara.");
regGS("This article cannot be previewed. Please make sure it has the article template selected.", "Tekst ne može biti pregledan. Proverite da li je odabran šablon za za prikaz teksta.");
regGS("This article cannot be previewed. Please make sure it has the front page template selected.", "Tekst ne može biti pregledan. Proverite da li je odabran šablon za prvu stranu.");
regGS("Insert Internal Link", "Napravi interni link");
regGS("No such article.", "Nema takvog teksta.");
regGS("No such section.", "Nema te rubrike.");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/sh/articles.php <==
<?php 
regGS("Select location:", "Izaberi lokaciju:");
regGS("You cannot have two articles in the same section with the same name.  The article name you specified is already in use by the article '$1'.", "Ne možete imati dva članka u jednoj rubrici sa istim imenom. Naslov koji ste uneli je već upotrebljen za članka '$1'.");
regGS("Visible to non-subscribers", "Vidljivo neprijavljenim korisnicima");
regGS("The article could not be published.", "Članak ne može biti objavljen");
regGS("Scheduled action deleted.", "Zakazane akcije su obrisane");
regGS("Scheduled action added.", "Akcija je zakazana");
regGS("Article(s) unlocked.", "Članak(a) otključan(o)");
regGS("Article(s) duplicated.", "Članak(a) dupliran(o)");
regGS("Article(s) deleted.", "Članak(a) obrisan(o)");
regGS("Article status set to '$1'", "Status članka postavljen na '$1'");
regGS("Article unlocked.", "Članak je otključan");
regGS("Article translation created.", "Napravljen je prevod članka");
regGS("Article order changed.", "Redosled članaka je promenjen");
regGS("Article moved.", "Članak je premešten.");
regGS("Article deleted.", "Članak je obrisan.");
regGS("Article created.", "Članak je kreiran.");
regGS("$1 toggled.", "$1 toggled.");
regGS("Total:", "Ukupno:");
regGS("Toggle '$1'", "Toggle '$1'");
regGS("Show Comments", "Prikaži komentare");
regGS("Saved:", "Snimljeno:");
regGS("Locked", "Zaključano");
regGS("Link to public page", "Link ka strani sa člankom");
regGS("Invalid type: $1", "Pogrešan tip: $1");
regGS("Hide Comments", "Sakri komentare");
regGS("Enabled", "Uključeni");
regGS("Disabled", "Isključeni");
regGS("Comments:", "Komentari:");
regGS("Comments", "Komentari");
regGS("The article has already been translated into $1.", "Tekst je već preveden na $1.");
regGS("You must set the publication, issue, and section for this article before you can schedule it for publishing.  Go to the \"$1\" menu and select \"$2\" to do this.", "Moraš odrediti publikaciju, izdanje i rubriku za ovaj tekst pre nego što mu zakažete automatsko objavljivanje. Idite u meni \"$1\" i izaberi \"$2\"");
regGS("You do not have the right to translate articles.", "Nemate pravo da prevodite tekstove.");
regGS("You do not have the right to publish articles.", "Nemate pravo da objavljujete tekstove.");
regGS("You do not have the right to move articles.", "Nemate pravo da premeštate tekstove.");
regGS("You cannot $1 the articles marked in red because the destination issue has not been translated into the appropriate language.", "Ne možete vršiti radnju \"$1\" na tekstovima naglašenim crvenom bojom jer ciljno izdanje nije prevedeno na odgovarajući jezik.");
regGS("Publish?", "Objavi?");
regGS("Publish articles", "Objavi tekstove");
regGS("Publish article", "Objavi tekst");
regGS("Move?", "Premesti?");
regGS("Move articles", "Premesti tekstove");
regGS("Move article", "Premesti tekst");
regGS("An issue must be created for the selected language but you do not have the right to create an issue.", "Mora biti kreirano izdanje za odabrani jezik, ali vi nemate pravo da kreirate izdanje.");
regGS("A section must be created for the selected language but you do not have the right to create a section.", "Mora biti kreirana rubrika za odabrani jezik, ali vi nemate pravo da kreirate rubriku.");
regGS("to section", "u rubriku");
regGS("You must select at least one article to perform an action.", "Morate izabrati najmanje jedan tekst da bi radnja bila izvršena.");
regGS("You must choose a language", "Morate izabrati jezik");
regGS("You may only translate one article at a time.", "Možete prevoditi samo jedan tekst u jednom trenutku.");
regGS("View article", "Pogledaj tekst");
regGS("Unable to create the section for translation $1.", "Ne može biti kreirana rubrika za prevod  $1.");
regGS("Unable to create the issue for translation $1.", "Ne može biti kreirano izdanje za prevod  $1.");
regGS("The following articles are new; it is not possible to schedule them for automatic publishing", "Sledeći tekstovi su novi; nemoguće je predvideti ih za automatsko objavljivanje");
regGS("Status: Submitted", "Status: predat");
regGS("Status: Submit", "Status: predaj");
regGS("Status: Set New", "Status: postavi novi");
regGS("Status: Published", "Status: objavljen");
regGS("Status: Publish", "Status: objavi");
regGS("Status: New", "Status: novi");
regGS("Section URL Name", "URL ime rubrike");
regGS("Section Name", "Ime rubrike");
regGS("Publish date", "Datum objavljivanja");
regGS("Publish Schedule", "Raspored objavljivanja");
regGS("No action specified", "Nije predviđena nikakva radnja");
regGS("New section name", "Novo ime rubrike");
regGS("New section URL name", "Novo URL ime rubrike");
regGS("New issue name", "novo ime izdanja");
regGS("New issue URL name", "Novo URL ime izdanja");
regGS("New article name", "Novo ime teksta");
regGS("Issue URL Name", "URL ime izdanja");
regGS("Issue Name", "Ime izdanja");
regGS("Files", "Fajlovi");
regGS("Duplicate?", "Dupliraj?");
regGS("Duplicate to another section", "dupliraj u drugu rubriku");
regGS("Duplicate articles", "dupliraj tekstove");
regGS("Article name ($1)", "Ime teksta ($1)");
regGS("Article List", "Lista tekstova");
regGS("Are you sure you want to remove the topic \'$1\' from the article?", "Da li ste sigurni da iz teksta želite da uklonite temu \'$1\'?");
regGS("Are you sure you want to remove the file \'$1\' from the article?", "Da li ste sigurni da iz teksta želite da uklonite fajl \'$1\'?");
regGS("Are you sure you want to remove the event scheduled on $1?", "Da li ste sigurni da želite da uklonite zakazanu akciju za $1?");
regGS("Are you sure you want to delete this article?", "Da li ste sigurni da želite da obrišete tekst?");
regGS("Are you sure you want to delete the selected articles?", "Da li ste sigurni da želite da obrišete izabrane tekstove?");
regGS("An issue must be created for the selected language.  Please enter the issue name and URL name.", "Mora biti kreirano izdanje za odabrani jezik. Unesite ime izdanja i URL ime.");
regGS("A section must be created for the selected language.  Please enter the section name and URL name.", "Mora biti kreirana rubrika za odabrani jezik. Unesite ime rubrike i URL ime.");
regGS("Article Type", "Tip teksta");
regGS("$1 articles found", "Pronađeno je $1 tekstova");
regGS("Show article on front page", "Prikaži tekst na početnoj strani");
regGS("Show article on section page", "Prikaži tekst na strani rubrike");
regGS("Translate article", "Prevedi tekst");
regGS("You do not have the right to change this article.  You may only edit your own articles and once submitted an article can only be changed by authorized users.", "Nemate pravo da menjate tekst. Možete pregledati jedino sopstvene tekstove, a jednom predati tekst može biti menjan samo od strane ovlašćenih korisnika");
regGS("Edit article", "Uredi tekst");
regGS("The article has been locked by $1 ($2) $3 hour(s) and $4 minute(s) ago.", "Tekst je zaključao $1 ($2) pre $3 časova i $4 minuta. ");
regGS("The article has been locked by $1 ($2) $3 minute(s) ago.", "Tekst je zaključao $1 ($2) pre $3 minuta. ");
regGS("Article is locked", "Tekst je zaključan");
regGS("Duplicate article", "Dupliraj tekst");
regGS("The destination section is the same as the source section.", "Ciljna rubrika je ista kao matična.");
regGS("The article is new; it is not possible to schedule it for automatic publishing.", "Tekst ima status novi; nemoguće je zakazati akciju automatskog objavljivanja.");
regGS("No article types were defined. You must create an article type first.", "Nema definisanih tipova tekstova. Morate kreirati neki.");
regGS("Edit article types", "Uredi tipove tekstova");
regGS("Could not save the article. It has been locked by $1 $2 hours and $3 minutes ago.", "Tekst ne može biti snimljen. Zaključan je od strane $1 pre $2časova i $3 minuta.");
regGS("You do not have the right to change this article status. Once submitted an article can only be changed by authorized users.", "Nemate pravo da menajte status teksta. Predatom tekstu status može promeniti samo ovlašćeni korisnik.");
regGS("You do not have the right to delete articles.", "Nemate pravo da brišete tekstove.");
regGS("You must select an article type.", "Morate izabrati tip teksta.");
regGS("Are you sure you want to remove the image \'$1\' from the article?", "Da li ste sigurni da iz teksta želite da uklonite sliku \'$1\'?");
regGS("There was an error reading request parameters.", "Greška pri čitanju traženih parametara.");
regGS("This article cannot be previewed. Please make sure it has the article template selected.", "Tekst ne može biti pregledan. Proverite da li je odabran šablon za za prikaz teksta.");
regGS("This article cannot be previewed. Please make sure it has the front page template selected.", "Tekst ne može biti pregledan. Proverite da li je odabran šablon za prvu stranu.");
regGS("Insert Internal Link", "Napravi interni link");
regGS("No such article.", "Nema takvog teksta.");
regGS("No such section.", "Nema te rubrike.");
regGS("Are you sure you want to delete this scheduled action?", " ");
regGS("Are you sure you want to remove the image '$1' from the article?", "Da li ste sigurni da želite da obrišete sliku $1 iz članka?");
regGS("Are you sure you want to remove the topic \\'$1\\' from the article?", "Da li ste sigurni da iz teksta želite da uklonite temu \\'$1\\'?");
regGS("Are you sure you want to remove the file \\'$1\\' from the article?", "Da li ste sigurni da iz teksta želite da uklonite fajl \\'$1\\'?");
regGS("Are you sure you want to remove the image \\'$1\\' from the article?", "Da li ste sigurni da iz teksta želite da uklonite sliku \\'$1\\'?");
?>
